summaryrefslogtreecommitdiffstats
path: root/src/borrowerdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/borrowerdialog.h')
-rw-r--r--src/borrowerdialog.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/src/borrowerdialog.h b/src/borrowerdialog.h
index 2ad2684..0b490b5 100644
--- a/src/borrowerdialog.h
+++ b/src/borrowerdialog.h
@@ -21,7 +21,7 @@ class KLineEdit;
#include <kdialogbase.h>
#include <klistview.h>
-#include <qdict.h>
+#include <tqdict.h>
namespace KABC {
class Addressee;
@@ -34,38 +34,39 @@ namespace Tellico {
*/
class BorrowerDialog : public KDialogBase {
Q_OBJECT
+ TQ_OBJECT
public:
- static Data::BorrowerPtr getBorrower(QWidget* parent);
+ static Data::BorrowerPtr getBorrower(TQWidget* tqparent);
private slots:
- void selectItem(const QString& name);
- void updateEdit(QListViewItem* item);
+ void selectItem(const TQString& name);
+ void updateEdit(TQListViewItem* item);
void slotLoadAddressBook();
private:
/**
* The constructor sets up the dialog.
*
* @param parent A pointer to the parent widget
* @param name The widget name
*/
- BorrowerDialog(QWidget* parent, const char* name=0);
+ BorrowerDialog(TQWidget* tqparent, const char* name=0);
Data::BorrowerPtr borrower();
- QString m_uid;
+ TQString m_uid;
KListView* m_listView;
KLineEdit* m_lineEdit;
- QDict<KListViewItem> m_itemDict;
+ TQDict<KListViewItem> m_itemDict;
class Item : public KListViewItem {
public:
- Item(KListView* parent, const KABC::Addressee& addressee);
- Item(KListView* parent, const Data::Borrower& borrower);
- const QString& uid() const { return m_uid; }
+ Item(KListView* tqparent, const KABC::Addressee& addressee);
+ Item(KListView* tqparent, const Data::Borrower& borrower);
+ const TQString& uid() const { return m_uid; }
private:
- QString m_uid;
+ TQString m_uid;
};
};
@@ -34,38 +34,39 @@ namespace Tellico {
* The constructor sets up the dialog.
*
- * @param parent A pointer to the parent widget
+ * @param tqparent A pointer to the tqparent widget
* @param name The widget name
*/